netapp_ontap.models.s3_policy_statement API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_policy_statement`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3PolicyStatementSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3PolicyStatement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `actions: List[str] GET POST PATCH`

    For each resource, S3 supports a set of operations. The resource operations allowed or denied are identified by an action list:

    - GetObject - retrieves objects from a bucket.
    - PutObject - puts objects in a bucket.
    - DeleteObject - deletes objects from a bucket.
    - ListBucket - lists the objects in a bucket.
    - GetBucketAcl - retrieves the access control list (ACL) of a bucket.
    - GetObjectAcl - retrieves the access control list (ACL) of an object.
    - ListAllMyBuckets - lists all of the buckets in a server.
    - ListBucketMultipartUploads - lists the multipart uploads in progress for a bucket.
    - ListMultipartUploadParts - lists the parts in a multipart upload.
    - CreateBucket - creates a new bucket.
    - DeleteBucket - deletes an existing bucket.
    - GetObjectTagging - retrieves the tag set of an object.
    - PutObjecttagging - sets the tag set for an object.
    - DeleteObjectTagging - deletes the tag set of an object.
    - GetBucketLocation - retrieves the location of a bucket.
    - GetBucketVersioning - retrieves the versioning configuration of a bucket.
    - PutBucketVersioning - modifies the versioning configuration of a bucket.
    - ListBucketVersions - lists the object versions in a bucket.
    - PutBucketPolicy - puts bucket policy on the bucket specified.
    - GetBucketPolicy - retrieves the bucket policy of a bucket.
    - DeleteBucketPolicy - deletes the policy created for a bucket. The wildcard character "*" can be used to form a regular expression for specifying actions.

    Example: ["*"]

  `effect: str GET POST PATCH`

    Specifies whether access is allowed or denied. If access (to allow) is not granted explicitly to a resource, access is implicitly denied. Access can also be denied explicitly to a resource, in order to make sure that a user cannot access it, even if a different policy grants access.

    Valid choices:

    - allow
    - deny
  `index: Size GET`

    Specifies a unique statement index used to identify a particular statement. This parameter should not be specified in the POST method. A statement index is automatically generated. It is not retrieved in the GET method.

  `resources: List[str] GET POST PATCH`

    The resources field of the s3_policy_statement.

    Example: ["bucket1","bucket1/*"]

  `sid: str GET POST PATCH`

    Specifies the statement identifier which contains additional information about the statement.

    Example: FullAccessToBucket1